Welcome to xyzzy1
=================

a magic trick in adventure

.. toctree::
   :maxdepth: 2

   xyzzy1
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
